Doubly robust estimators of the coefficients in the two regression
onearmglmcount.dr(y, x.cate, time, trt, ps, f.predictor)Doubly robust estimators of the regression coefficients beta_r in the doubly robust estimating equation
where r = 0, 1 is treatment received; vector of size p + 1 (intercept included)
Observed outcome; vector of size n
Matrix of p baseline covariates; dimension n by p
Log-transformed person-years of follow-up; vector of size n
Treatment received; vector of size n units with treatment coded as 0/1
Estimated propensity scores for all observations; vector of size n
Initial prediction of the outcome (expected number of relapses for one unit of exposure time) conditioned
on the covariates x for one treatment group r; mu_r(x), step 1 in the two regression; vector of size n